def read(file_path: str) -> str:
    with open(file_path, "r") as file:
        return file.read()


def readlines(file_path: str) -> list:
    with open(file_path, "r") as file:
        return file.readlines()


def write(file_path: str, content: str) -> None:
    with open(file_path, "w") as file:
        file.write(content)


def writelines(file_path: str, contents: list, endline="\n") -> None:
    with open(file_path, "w") as file:
        for content in contents:
            file.write(content + endline)



import json


def read(json_file_path: str) -> dict:
    """Function reading a json file and returning a list of
    dictionaries with block definitions.

    :param json_file_path: a path to a json file
    :return: a list of dictionaries with geometry definition (block definition)
    """
    with open(json_file_path) as f:
        return json.load(f)


def write(file_path: str, content: dict) -> None:
    with open(file_path, "w") as file:
        json.dump(content, file)



import os
from pathlib import Path


def check_if_file_exists(file_path: str) -> None:
    """function checking whether a file exists. If not, then a FileNotFoundError is raised.

    :param file_path: a path to a file whose presence is verified.
    """
    if not os.path.isfile(file_path):
        raise FileNotFoundError("The file %s does not exist!" % file_path)


def create_directory_if_nonexistent(output_dir: Path) -> None:
    """Function checking whether a directory exists, if not then it is created

    :param output_dir: a path to an output directory
    """
    is_dir = Path(output_dir).is_dir()
    if not is_dir:
        os.mkdir(output_dir)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pymbse', 'pymbse.commons']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'pymbse-commons',
    'version': '0.0.5',
    'description': '',
    'long_description': '# PyMBSE Commons\n\nProject with common functions used across all projects in the CHART-MagNum group.\n\n',
    'author': 'mmaciejewski',
    'author_email': 'michal.maciejewski@ief.ee.ethz.ch',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://gitlab.cern.ch/chart-magnum/pymbse-commons',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
